<?php

namespace Bixo\Search\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Search\Http\Requests\SearchesRequest;
use Bixo\Search\Interfaces\SearchesRepositoryInterface;
use Bixo\Search\Models\Searches;
use Bixo\Search\Forms\Searches as Form;

/**
 * APIController  class for searches.
 */
class SearchesAPIController extends BaseController
{

    /**
     * Initialize searches resource controller.
     *
     * @param type SearchesRepositoryInterface $searches
     *
     * @return null
     */
    public function __construct(SearchesRepositoryInterface $searches)
    {
        parent::__construct();
        $this->repository = $searches;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Search\Repositories\Criteria\SearchesResourceCriteria::class);
    }

    /**
     * Display a list of searches.
     *
     * @return Response
     */
    public function index(SearchesRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Search\Repositories\Presenter\SearchesPresenter::class)
            ->paginate();
    }

    /**
     * Display searches.
     *
     * @param Request $request
     * @param Model   $searches
     *
     * @return Response
     */
    public function show(SearchesRequest $request, Searches $searches)
    {
        return $searches->setPresenter(\Bixo\Search\Repositories\Presenter\SearchesListPresenter::class);
        ;
    }

    /**
     * Create new searches.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SearchesRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('search::searches.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('search/searches/' . $searches->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/searches');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the searches.
     *
     * @param Request $request
     * @param Model   $searches
     *
     * @return Response
     */
    public function update(SearchesRequest $request, Searches $searches)
    {
        try {
            $data = $request->all();

            $searches->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('search::searches.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('search/searches/' . $searches->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/searches/' . $searches->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the searches.
     *
     * @param Model   $searches
     *
     * @return Response
     */
    public function destroy(SearchesRequest $request, Searches $searches)
    {
        try {
            $searches->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('search::searches.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('search/searches/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('search/searches/' . $searches->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
