<?php

namespace Bixo\Search\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Search\Models\Searches;

class SearchesPolicy
{

    /**
     * Determine if the given user can view the searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function view(UserPolicy $user, Searches $searches)
    {
        if ($user->canDo('search.searches.view') && $user->isAdmin()) {
            return true;
        }

        return $searches->user_id == user_id() && $searches->user_type == user_type();
    }

    /**
     * Determine if the given user can create a searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('search.searches.create');
    }

    /**
     * Determine if the given user can update the given searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function update(UserPolicy $user, Searches $searches)
    {
        if ($user->canDo('search.searches.edit') && $user->isAdmin()) {
            return true;
        }

        return $searches->user_id == user_id() && $searches->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Searches $searches)
    {
        return $searches->user_id == user_id() && $searches->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Searches $searches)
    {
        if ($user->canDo('search.searches.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given searches.
     *
     * @param UserPolicy $user
     * @param Searches $searches
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Searches $searches)
    {
        if ($user->canDo('search.searches.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
